@@ -27,7 +27,8 @@
 #include "cr-enc-handler.h"
 
 /**
- *@file
+ *@CRInput:
+ *
  *The definition of the #CRInput class.
  */
 
@@ -112,15 +113,17 @@ cr_input_new_real (void)
  ***************/
 
 /**
- *Creates a new input stream from a memory buffer.
- *@param a_buf the memory buffer to create the input stream from.
+ * cr_input_new_from_buf:
+ *@a_buf: the memory buffer to create the input stream from.
  *The #CRInput keeps this pointer so user should not free it !.
- *@param a_len the size of the input buffer.
- *@param a_enc the buffer's encoding.
- *@param a_free_buf if set to TRUE, this a_buf will be freed
+ *@a_len: the size of the input buffer.
+ *@a_enc: the buffer's encoding.
+ *@a_free_buf: if set to TRUE, this a_buf will be freed
  *at the destruction of this instance. If set to false, it is up
  *to the caller to free it.
- *@return the newly built instance of #CRInput.
+ *
+ *Creates a new input stream from a memory buffer.
+ *Returns the newly built instance of #CRInput.
  */
 CRInput *
 cr_input_new_from_buf (guchar * a_buf,
@@ -177,13 +180,14 @@ cr_input_new_from_buf (guchar * a_buf,
 }
 
 /**
+ * cr_input_new_from_uri:
+ *@a_file_uri: the file to create *the input stream from.
+ *@a_enc: the encoding of the file *to create the input from.
+ *
  *Creates a new input stream from
  *a file.
- *@param a_file_uri the file to create
- *the input stream from.
- *@param a_enc the encoding of the file
- *to create the input from
- *@return the newly created input stream if
+ *
+ *Returns the newly created input stream if
  *this method could read the file and create it,
  *NULL otherwise.
  */
@@ -270,8 +274,10 @@ cr_input_new_from_uri (const gchar * a_file_uri, enum CREncoding a_enc)
 }
 
 /**
+ * cr_input_destroy:
+ *@a_this: the current instance of #CRInput.
+ *
  *The destructor of the #CRInput class.
- *@param a_this the current instance of #CRInput.
  */
 void
 cr_input_destroy (CRInput * a_this)
@@ -293,9 +299,11 @@ cr_input_destroy (CRInput * a_this)
 }
 
 /**
+ * cr_input_ref:
+ *@a_this: the current instance of #CRInput.
+ *
  *Increments the reference count of the current
  *instance of #CRInput.
- *@param a_this the current instance of #CRInput.
  */
 void
 cr_input_ref (CRInput * a_this)
@@ -306,11 +314,14 @@ cr_input_ref (CRInput * a_this)
 }
 
 /**
+ * cr_input_unref:
+ *@a_this: the current instance of #CRInput.
+ *
  *Decrements the reference count of this instance
  *of #CRInput. If the reference count goes down to
  *zero, this instance is destroyed.
- *@param a_this the current instance of #CRInput.
  *
+ * Returns TRUE if the instance of #CRInput got destroyed, false otherwise.
  */
 gboolean
 cr_input_unref (CRInput * a_this)
@@ -329,15 +340,18 @@ cr_input_unref (CRInput * a_this)
 }
 
 /**
- *Tests wether the current instance of
- *#CRInput has reached its input buffer.
- *@param a_this the current instance of #CRInput.
- *@param a_end_of_input out parameter. Is set to TRUE if
+ * cr_input_end_of_input:
+ *@a_this: the current instance of #CRInput.
+ *@a_end_of_input: out parameter. Is set to TRUE if
  *the current instance has reached the end of its input buffer,
  *FALSE otherwise.
- *@param CR_OK upon successful completion, an error code otherwise.
- *Note that all the out parameters of this method are valid if
- *and only if this method returns CR_OK.
+ *
+ *Tests wether the current instance of
+ *#CRInput has reached its input buffer.
+ *
+ * Returns CR_OK upon successful completion, an error code otherwise.
+ * Note that all the out parameters of this method are valid if
+ * and only if this method returns CR_OK.
  */
 enum CRStatus
 cr_input_end_of_input (CRInput * a_this, gboolean * a_end_of_input)
@@ -352,10 +366,11 @@ cr_input_end_of_input (CRInput * a_this, gboolean * a_end_of_input)
 }
 
 /**
+ * cr_input_get_nb_bytes_left:
+ *@a_this: the current instance of #CRInput.
+ *
  *Returns the number of bytes left in the input stream
- *before the end.
- *@param a_this the current instance of #CRInput.
- *@return the number of characters left or -1 in case of error.
+ *before the end, -1 in case of error.
  */
 glong
 cr_input_get_nb_bytes_left (CRInput * a_this)
@@ -373,14 +388,16 @@ cr_input_get_nb_bytes_left (CRInput * a_this)
 }
 
 /**
- *Returns the next byte of the input.
- *Update the state of the input so that
+ * cr_input_read_byte:
+ *@a_this: the current instance of #CRInput.
+ *@a_byte: out parameter the returned byte.
+ *
+ *Gets the next byte of the input.
+ *Updates the state of the input so that
  *the next invocation of this method  returns
  *the next coming byte.
  *
- *@param a_this the current instance of #CRInput.
- *@param a_byte out parameter the returned byte.
- *@return CR_OK upon successful completion, an error code
+ *Returns CR_OK upon successful completion, an error code
  *otherwise. All the out parameters of this method are valid if
  *and only if this method returns CR_OK.
  */
@@ -409,11 +426,14 @@ cr_input_read_byte (CRInput * a_this, guchar * a_byte)
 }
 
 /**
+ * cr_input_read_char:
+ *@a_this: the current instance of CRInput.
+ *@a_char: out parameter. The read character.
+ *
  *Reads an unicode character from the current instance of
  *#CRInput.
- *@param a_this the current instance of CRInput.
- *@param a_char out parameter. The read character.
- *@return CR_OK upon successful completion, an error code
+ *
+ *Returns CR_OK upon successful completion, an error code
  *otherwise.
  */
 enum CRStatus
@@ -464,11 +484,13 @@ cr_input_read_char (CRInput * a_this, guint32 * a_char)
 }
 
 /**
+ * cr_input_set_line_num:
+ *@a_this: the "this pointer" of the current instance of #CRInput.
+ *@a_line_num: the new line number.
+ *
  *Setter of the current line number.
- *@param a_this the "this pointer" of the current instance of
- *#CRInput.
- *@param a_line_num the new line number.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Return CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_set_line_num (CRInput * a_this, glong a_line_num)
@@ -481,11 +503,13 @@ cr_input_set_line_num (CRInput * a_this, glong a_line_num)
 }
 
 /**
+ * cr_input_get_line_num:
+ *@a_this: the "this pointer" of the current instance of #CRInput.
+ *@a_line_num: the returned line number.
+ *
  *Getter of the current line number.
- *@param a_this the "this pointer" of the current instance of
- *#CRInput.
- *@param a_line_num the returned line number.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_get_line_num (CRInput * a_this, glong * a_line_num)
@@ -499,11 +523,13 @@ cr_input_get_line_num (CRInput * a_this, glong * a_line_num)
 }
 
 /**
+ * cr_input_set_column_num:
+ *@a_this: the "this pointer" of the current instance of #CRInput.
+ *@a_col: the new column number.
+ *
  *Setter of the current column number.
- *@param a_this the "this pointer" of the current instance of
- *#CRInput.
- *@param a_col the new column number.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_set_column_num (CRInput * a_this, glong a_col)
@@ -516,11 +542,13 @@ cr_input_set_column_num (CRInput * a_this, glong a_col)
 }
 
 /**
+ * cr_input_get_column_num:
+ *@a_this: the "this pointer" of the current instance of #CRInput.
+ *@a_col: out parameter
+ *
  *Getter of the current column number.
- *@param a_this the "this pointer" of the current instance of
- *#CRInput.
- *@param a_col out parameter
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_get_column_num (CRInput * a_this, glong * a_col)
@@ -534,10 +562,13 @@ cr_input_get_column_num (CRInput * a_this, glong * a_col)
 }
 
 /**
+ * cr_input_increment_line_num:
+ *@a_this: the "this pointer" of the current instance of #CRInput.
+ *@a_increment: the increment to add to the line number.
+ *
  *Increments the current line number.
- *@param a_this the "this pointer" of the current instance of
- *#CRInput.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_increment_line_num (CRInput * a_this, glong a_increment)
@@ -550,10 +581,13 @@ cr_input_increment_line_num (CRInput * a_this, glong a_increment)
 }
 
 /**
+ * cr_input_increment_col_num:
+ *@a_this: the "this pointer" of the current instance of #CRInput.
+ *@a_increment: the increment to add to the column number.
+ *
  *Increments the current column number.
- *@param a_this the "this pointer" of the current instance of
- *#CRInput.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_increment_col_num (CRInput * a_this, glong a_increment)
@@ -566,13 +600,15 @@ cr_input_increment_col_num (CRInput * a_this, glong a_increment)
 }
 
 /**
+ * cr_input_consume_char:
+ *@a_this: the this pointer.
+ *@a_char: the character to consume. If set to zero,
+ *consumes any character.
+ *
  *Consumes the next character of the input stream if
  *and only if that character equals a_char.
  *
- *@param a_this the this pointer.
- *@param a_char the character to consume. If set to zero,
- *consumes any character.
- *@return CR_OK upon successful completion, CR_PARSING_ERROR if
+ *Returns CR_OK upon successful completion, CR_PARSING_ERROR if
  *next char is different from a_char, an other error code otherwise
  */
 enum CRStatus
@@ -597,21 +633,23 @@ cr_input_consume_char (CRInput * a_this, guint32 a_char)
 }
 
 /**
+ * cr_input_consume_chars:
+ *@a_this: the this pointer of the current instance of #CRInput.
+ *@a_char: the character to consume.
+ *@a_nb_char: in/out parameter. The number of characters to consume.
+ *If set to a negative value, the function will consume all the occurences
+ *of a_char found.
+ *After return, if the return value equals CR_OK, this variable contains 
+ *the number of characters actually consumed.
+ *
  *Consumes up to a_nb_char occurences of the next contiguous characters 
  *which equal a_char. Note that the next character of the input stream
  **MUST* equal a_char to trigger the consumption, or else, the error
  *code CR_PARSING_ERROR is returned.
  *If the number of contiguous characters that equals a_char is less than
  *a_nb_char, then this function consumes all the characters it can consume.
- *
- *@param a_this the this pointer of the current instance of #CRInput.
- *@param a_char the character to consume.
- *@param a_nb_char in/out parameter. The number of characters to consume.
- *If set to a negative value, the function will consume all the occurences
- *of a_char found.
- *After return, if the return value equals CR_OK, this variable contains 
- *the number of characters actually consumed.
- *@return CR_OK if at least one character has been consumed, an error code
+ * 
+ *Returns CR_OK if at least one character has been consumed, an error code
  *otherwise.
  */
 enum CRStatus
@@ -645,13 +683,15 @@ cr_input_consume_chars (CRInput * a_this, guint32 a_char, gulong * a_nb_char)
 }
 
 /**
+ * cr_input_consume_white_spaces:
+ *@a_this: the "this pointer" of the current instance of #CRInput.
+ *@a_nb_chars: in/out parameter. The number of white spaces to
+ *consume. After return, holds the number of white spaces actually consumed.
+ *
  *Same as cr_input_consume_chars() but this one consumes white
  *spaces.
  *
- *@param a_this the "this pointer" of the current instance of #CRInput.
- *@param a_nb_chars in/out parameter. The number of white spaces to
- *consume. After return, holds the number of white spaces actually consumed.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_consume_white_spaces (CRInput * a_this, gulong * a_nb_chars)
@@ -690,13 +730,16 @@ cr_input_consume_white_spaces (CRInput * a_this, gulong * a_nb_chars)
 }
 
 /**
+ * cr_input_peek_char:
+ *@a_this: the current instance of #CRInput.
+ *@a_char: out parameter. The returned character.
+ *
  *Same as cr_input_read_char() but does not update the
  *internal state of the input stream. The next call
  *to cr_input_peek_char() or cr_input_read_char() will thus
  *return the same character as the current one.
- *@param a_this the current instance of #CRInput.
- *@param a_char out parameter. The returned character.
- *@return CR_OK upon successful completion, an error code
+ *
+ *Returns CR_OK upon successful completion, an error code
  *otherwise.
  */
 enum CRStatus
@@ -729,6 +772,14 @@ cr_input_peek_char (CRInput * a_this, guint32 * a_char)
 }
 
 /**
+ * cr_input_peek_byte:
+ *@a_this: the current instance of #CRInput.
+ *@a_origin: the origin to consider in the calculation
+ *of the position of the byte to peek.
+ *@a_offset: the offset of the byte to peek, starting from
+ *the origin specified by a_origin.
+ *@a_byte: out parameter the peeked byte.
+ *
  *Gets a byte from the input stream,
  *starting from the current position in the input stream.
  *Unlike cr_input_peek_next_byte() this method
@@ -736,18 +787,9 @@ cr_input_peek_char (CRInput * a_this, guint32 * a_char)
  *Subsequent calls to cr_input_peek_byte with the same arguments
  *will return the same byte.
  *
- *@param a_this the current instance of #CRInput.
- *@param a_origin the origin to consider in the calculation
- *of the position of the byte to peek.
- *@param a_offset the offset of the byte to peek, starting from
- *the origin specified by a_origin.
- *@param a_byte out parameter the peeked byte.
- *@return CR_OK upon successful completion or,
- *
- *<ul>
- *<li>CR_BAD_PARAM_ERROR if at least one of the parameters is invalid</li>
- *<li>CR_OUT_OF_BOUNDS_ERROR if the indexed byte is out of bounds</li>
- *</ul>
+ *Returns CR_OK upon successful completion or,
+ *CR_BAD_PARAM_ERROR if at least one of the parameters is invalid;
+ *CR_OUT_OF_BOUNDS_ERROR if the indexed byte is out of bounds.
  */
 enum CRStatus
 cr_input_peek_byte (CRInput * a_this, enum CRSeekPos a_origin,
@@ -788,15 +830,18 @@ cr_input_peek_byte (CRInput * a_this, enum CRSeekPos a_origin,
 }
 
 /**
- *Same as cr_input_peek_byte() but with a simplified
- *interface.
- *@param a_this the current byte input stream.
- *@param a_offset the offset of the byte to peek, starting
+ * cr_input_peek_byte2:
+ *@a_this: the current byte input stream.
+ *@a_offset: the offset of the byte to peek, starting
  *from the current input position pointer.
- *@param a_eof out parameter. Is set to true is we reach end of
+ *@a_eof: out parameter. Is set to true is we reach end of
  *stream. If set to NULL by the caller, this parameter is not taken
  *in account.
- *@return the read byte or 0 if something bad happened.
+ *
+ *Same as cr_input_peek_byte() but with a simplified
+ *interface.
+ *
+ *Returns the read byte or 0 if something bad happened.
  */
 guchar
 cr_input_peek_byte2 (CRInput * a_this, gulong a_offset, gboolean * a_eof)
@@ -819,12 +864,15 @@ cr_input_peek_byte2 (CRInput * a_this, gulong a_offset, gboolean * a_eof)
 }
 
 /**
- *Returns the memory address of the byte located at a given offset
- *in the input stream.
- *@param a_this the current instance of #CRInput.
- *@param a_offset the offset of the byte in the input stream starting
+ * cr_input_get_byte_addr:
+ *@a_this: the current instance of #CRInput.
+ *@a_offset: the offset of the byte in the input stream starting
  *from the beginning of the stream.
- *@return the address, otherwise NULL if an error occured.
+ *
+ *Gets the memory address of the byte located at a given offset
+ *in the input stream.
+ *
+ *Returns the address, otherwise NULL if an error occured.
  */
 guchar *
 cr_input_get_byte_addr (CRInput * a_this, gulong a_offset)
@@ -839,10 +887,13 @@ cr_input_get_byte_addr (CRInput * a_this, gulong a_offset)
 }
 
 /**
- *Returns the address of the current character pointer.
- *@param a_this the current input stream
- *@param a_offset out parameter. The returned address.
- *@return CR_OK upon successful completion, an error code otherwise.
+ * cr_input_get_cur_byte_addr:
+ *@a_this: the current input stream
+ *@a_offset: out parameter. The returned address.
+ *
+ *Gets the address of the current character pointer.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_get_cur_byte_addr (CRInput * a_this, guchar ** a_offset)
@@ -861,23 +912,20 @@ cr_input_get_cur_byte_addr (CRInput * a_this, guchar ** a_offset)
 }
 
 /**
+ * cr_input_seek_index:
+ *@a_this: the current instance of #CRInput.
+ *@a_origin: the origin to consider during the calculation
+ *of the absolute position of the new "current byte index".
+ *@a_pos: the relative offset of the new "current byte index."
+ *This offset is relative to the origin a_origin.
+ *
  *Sets the "current byte index" of the current instance
  *of #CRInput. Next call to cr_input_get_byte() will return
  *the byte next after the new "current byte index".
  *
- *@param a_this the current instance of #CRInput.
- *
- *@param a_origin the origin to consider during the calculation
- *of the absolute position of the new "current byte index".
- *
- *@param a_pos the relative offset of the new "current byte index."
- *This offset is relative to the origin a_origin.
- *
- *@return CR_OK upon successful completion otherwise returns
- *<ul>
- *<li>CR_BAD_PARAM_ERROR if at least one of the parameters is not valid</li>
- *<li>CR_OUT_BOUNDS_ERROR</li>
- *</ul>
+ *Returns CR_OK upon successful completion otherwise returns
+ *CR_BAD_PARAM_ERROR if at least one of the parameters is not valid
+ *or CR_OUT_BOUNDS_ERROR in case of error.
  */
 enum CRStatus
 cr_input_seek_index (CRInput * a_this, enum CRSeekPos a_origin, gint a_pos)
@@ -918,21 +966,19 @@ cr_input_seek_index (CRInput * a_this, enum CRSeekPos a_origin, gint a_pos)
 }
 
 /**
+ * cr_input_get_cur_pos:
+ *@a_this: the current instance of #CRInput.
+ *@a_pos: out parameter. The returned position.
+ *
  *Gets the position of the "current byte index" which
  *is basically the position of the last returned byte in the
  *input stream.
  *
- *@param a_this the current instance of #CRInput.
- *
- *@param a_pos out parameter. The returned position.
- *
- *@return CR_OK upon successful completion. Otherwise,
- *<ul>
- *<li>CR_BAD_PARAMETER_ERROR if at least one of the arguments is invalid.</li>
- *<li>CR_START_OF_INPUT if no call to either cr_input_read_byte()
+ *Returns CR_OK upon successful completion. Otherwise,
+ *CR_BAD_PARAMETER_ERROR if at least one of the arguments is invalid.
+ *CR_START_OF_INPUT if no call to either cr_input_read_byte()
  *or cr_input_seek_index() have been issued before calling 
- *cr_input_get_cur_pos()</li>
- *</ul>
+ *cr_input_get_cur_pos()
  *Note that the out parameters of this function are valid if and only if this
  *function returns CR_OK.
  */
@@ -952,13 +998,16 @@ cr_input_get_cur_pos (CRInput * a_this, CRInputPos * a_pos)
 }
 
 /**
+ * cr_input_get_parsing_location:
+ *@a_this: the current instance of #CRInput
+ *@a_loc: the set parsing location.
+ *
  *Gets the current parsing location.
  *The Parsing location is a public datastructure that
  *represents the current line/column/byte offset/ in the input
  *stream.
- *@param a_this the current instance of #CRInput
- *@param a_loc the set parsing location.
- *@return CR_OK upon successful completion, an error
+ *
+ *Returns CR_OK upon successful completion, an error
  *code otherwise.
  */
 enum CRStatus
@@ -981,13 +1030,16 @@ cr_input_get_parsing_location (CRInput *a_this,
 }
 
 /**
+ * cr_input_get_cur_index:
+ *@a_this: the "this pointer" of the current instance of
+ *#CRInput
+ *@a_index: out parameter. The returned index.
+ *
  *Getter of the next byte index. 
  *It actually returns the index of the
  *next byte to be read.
- *@param a_this the "this pointer" of the current instance of
- *#CRInput
- *@param a_index out parameter. The returned index.
- *@return CR_OK upon successful completion, an error code
+ *
+ *Returns CR_OK upon successful completion, an error code
  *otherwise.
  */
 enum CRStatus
@@ -1002,12 +1054,15 @@ cr_input_get_cur_index (CRInput * a_this, glong * a_index)
 }
 
 /**
+ * cr_input_set_cur_index:
+ *@a_this: the "this pointer" of the current instance
+ *of #CRInput .
+ *@a_index: the new index to set.
+ *
  *Setter of the next byte index.
  *It sets the index of the next byte to be read.
- *@param a_this the "this pointer" of the current instance
- *of #CRInput .
- *@param a_index the new index to set.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_set_cur_index (CRInput * a_this, glong a_index)
@@ -1020,10 +1075,13 @@ cr_input_set_cur_index (CRInput * a_this, glong a_index)
 }
 
 /**
+ * cr_input_set_end_of_file:
+ *@a_this: the current instance of #CRInput.
+ *@a_eof: the new end of file flag.
+ *
  *Sets the end of file flag.
- *@param a_this the current instance of #CRInput.
- *@param a_eof the new end of file flag.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_set_end_of_file (CRInput * a_this, gboolean a_eof)
@@ -1036,11 +1094,14 @@ cr_input_set_end_of_file (CRInput * a_this, gboolean a_eof)
 }
 
 /**
- *Gets the end of file flag.
- *@param a_this the current instance of #CRInput.
- *@param a_eof out parameter the place to put the end of
+ * cr_input_get_end_of_file:
+ *@a_this: the current instance of #CRInput.
+ *@a_eof: out parameter the place to put the end of
  *file flag.
- *@return CR_OK upon successful completion, an error code otherwise.
+ *
+ *Gets the end of file flag.
+ *
+ *Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_get_end_of_file (CRInput * a_this, gboolean * a_eof)
@@ -1054,10 +1115,13 @@ cr_input_get_end_of_file (CRInput * a_this, gboolean * a_eof)
 }
 
 /**
+ * cr_input_set_end_of_line:
+ *@a_this: the current instance of #CRInput.
+ *@a_eol: the new end of line flag.
+ *
  *Sets the end of line flag.
- *@param a_this the current instance of #CRInput.
- *@param a_eol the new end of line flag.
- *@return CR_OK upon successful completion, an error code
+ *
+ *Returns CR_OK upon successful completion, an error code
  *otherwise.
  */
 enum CRStatus
@@ -1071,11 +1135,14 @@ cr_input_set_end_of_line (CRInput * a_this, gboolean a_eol)
 }
 
 /**
- *Gets the end of line flag of the current input.
- *@param a_this the current instance of #CRInput
- *@param a_eol out parameter. The place to put
+ * cr_input_get_end_of_line:
+ *@a_this: the current instance of #CRInput
+ *@a_eol: out parameter. The place to put
  *the returned flag
- *@return CR_OK upon successful completion, an error code
+ *
+ *Gets the end of line flag of the current input.
+ *
+ *Returns CR_OK upon successful completion, an error code
  *otherwise.
  */
 enum CRStatus
@@ -1090,11 +1157,14 @@ cr_input_get_end_of_line (CRInput * a_this, gboolean * a_eol)
 }
 
 /**
+ * cr_input_set_cur_pos:
+ *@a_this: the "this pointer" of the current instance of
+ *#CRInput.
+ *@a_pos: the new position.
+ *
  *Sets the current position in the input stream.
  *
- *@param a_this the "this pointer" of the current instance of
- *#CRInput.
- *@param a_pos the new position.
+ * Returns CR_OK upon successful completion, an error code otherwise.
  */
 enum CRStatus
 cr_input_set_cur_pos (CRInput * a_this, CRInputPos * a_pos)
